<?php

namespace App\Http\Livewire;

use Livewire\Component;
use OpenAI\Laravel\Facades\OpenAI; 
use App\Models\WpBlog;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Auth;

class CreatePost extends Component

{
   /**
     * The blog title.
     *
     * @var string
     */
    public $blogTitle;

    /**
     * The section titles.
     *
     * @var array
     */
    public $sectionTitles = [];

    /**
     * The blog post content.
     *
     * @var string
     */
    public $content;

    public $editor;

    public $language;

    public $userblogs;

    public $mycontent;

    public $blog;
    
    private $promptone;

    private $prompttwo;

    public $activeblog;

    public $publishStatus;

    private $blog_user;

    private $blog_password;
    
    private $wpWebsite;

    public $postId;



    /**
     * Create a long form blog post.
     *
     * @return void
     */


     public function mount()
     {
         $this->userId = Auth::user()->id;
         $this->userblogs = WpBlog::where('user_id', $this->userId)->get();
         if (env('OPENAI_API_KEY') == '') {
            session()->flash('error', 'Set your OpenAI API key in .env file to use this feature');
            return;
        }
     }



    public function createPost()
    {


        $this->validate([
            'blogTitle' => 'required',
            'sectionTitles' => 'required|array|min:1',
            'sectionTitles.*' => 'required|string',
        ]);
        
        if (env('OPENAI_API_KEY') == '') {
            session()->flash('error', 'Set your OpenAI API key in .env file to use this feature');
            return;
        }
        

        if (env('UNSPLASH_ACCESS_KEY') == '') {
            session()->flash('error', 'Unsplash API key is not set in .env file');
            return;
        }
        

        $this->content = '';
        $this->content .= '<h1>' . $this->blogTitle . '</h1>';

        // Loop through the section titles and generate content for each section.
        
        try {
            foreach ($this->sectionTitles as $sectionTitle) {

                $blogcontent = OpenAI::completions()->create([
                       'model' => 'text-davinci-003',
                       'prompt' => "Write a high quality blog section in " . $this->language . " based on the following:\n\nBlog Post Title: " . $this->blogTitle . "\n\nSection Title: " . $sectionTitle,
                       'max_tokens' => 1000,
                   ]);
       
               // Get the generated text from the API response
               $sectionContent = $blogcontent->choices[0]->text;
       
               // Connect to Unsplash API and get a random image based on the section title
               $response = Http::get('https://api.unsplash.com/search/photos', [
                   'query' => $sectionTitle,
                   'client_id' => env('UNSPLASH_ACCESS_KEY'),
               ]);
       
               // If the API response is empty, add a default image
               if (empty($response->json()['results'])) {
                   $imageUrl = 'https://source.unsplash.com/1600x900/?AI';
               } else {
                   // Get the image URL from the API response
                   $imageUrl = $response->json()['results'][0]['urls']['regular'];
               }
       
              
               // Add the image to the blog post content
               $this->content .= '<img src="' . $imageUrl . '" alt="' . $sectionTitle . '" style="width:100%">' . '<br> <br>' . '<strong>' . $sectionTitle . '</strong>' . '<br>' . $sectionContent . '<br> <br>';
                  
       
               }
        } catch (\Exception $e) {
            session()->flash('error', 'There was an error generating content for your blog post. Please try again.');
            return;
        }
        
        

    }

        public function addSubheading()
    {
        if (count($this->sectionTitles) < 5) {
            $this->sectionTitles[] = '';
        }
    }

    // Post content to WordPress
    public function postToWordPress()
    {

        // Validate the blog post content
        $this->validate([
            'content' => 'required|min:100',
            'blog' => 'required',
        ]);

    // Get the blog details from the database
    $this->activeblog = WpBlog::where('id', $this->blog)->where('user_id', $this->userId)->first();
    $this->blog_user = $this->activeblog->username;
    $this->blog_pass = $this->activeblog->password;
    $this->wpWebsite = $this->activeblog->wp_blog_name;

    // Post to Wordpress
    $response = Http::withHeaders([ 'Authorization' 
     => 'Basic ' . base64_encode($this->blog_user . ':' . $this->blog_pass)])->post($this->wpWebsite . '/wp-json/wp/v2/posts', [
        'title' => $this->blogTitle,
        'content' => $this->content,
        'status' =>  $this->publishStatus,
    ]);


    //If Success Redirect to Dashboard with Success Message else Flash with Error Message
    if ($response->successful()) {
        session()->flash('success', 'Your content was posted to Wordpress successfully!');
        return redirect()->route('dashboard')->with('success', 'Your post was created successfully!');
    } else {
        session()->flash('error', 'Your content was not posted to Wordpress!');
        return redirect()->route('dashboard')->with('error', 'Your post was not created!');
    }

    }
             

    public function render()
    {
        return view('livewire.create-post');
    }
}