<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\WpBlog;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;


class WpBlogs extends Component
{
    public $wpBlogName;
    public $username;
    public $password;
    public $userId;

    public function mount()
    {
        $this->userId = Auth::id();
    }

    public function saveWpBlog()
    {
        // Strip http if exist and add https:// to the wpBlogName
        if (strpos($this->wpBlogName, 'http://') !== false)
        {
            $this->wpBlogName = str_replace('http://', 'https://', $this->wpBlogName);
        }

        // If wpBlogName does not contain https://, add it
        if (strpos($this->wpBlogName, 'https://') === false)
        {
            $this->wpBlogName = 'https://'.$this->wpBlogName;
        }
        
        // If wpBlogName is not unique, flash error message
        
        if (WpBlog::where('wp_blog_name', $this->wpBlogName)->exists()) {
            session()->flash('error', 'Domain already exists.');
            return;
        }

        $this->validate([
            'wpBlogName' => 'required|url|unique:wp_blogs,wp_blog_name',
            'username' => 'required',
            'password' => 'required'
        ]);
 
        // Validate Wordpress login.
        try {
            $response = Http::withHeaders([ 'Authorization' 
            => 'Basic ' . base64_encode($this->username . ':' . $this->password)])->get($this->wpBlogName.'/wp-json/wp/v2/users/me');
        } catch (\Exception $e) {
            session()->flash('error', 'Domain or login details may be invalid.');
            return;
        }

        // If response is not OK, flash error message
        if ($response->status() != 200) {
            session()->flash('error', 'Wordpress username or password is incorrect.');
            return;
        }
        

        $wpBlog = WpBlog::create([
            'wp_blog_name' => $this->wpBlogName,
            'username' => $this->username,
            'password' => $this->password,
            'user_id' => $this->userId
        ]);

        // Reset the form
        $this->wpBlogName = '';
        $this->username = '';
        $this->password = '';
        
        // If success flash success message else flash error message
        if ($wpBlog) {
            session()->flash('success', 'Wordpress blog added successfully.');
        } else {
            session()->flash('error', 'There was an error adding the Wordpress blog.');
        }

    }

    public function getWpBlogs()
    {
        
        return WpBlog::where('user_id', $this->userId)->get();
    }

    public function render()
    {
        $wpBlogs = $this->getWpBlogs();

        return view('livewire.wp-blogs', compact('wpBlogs'));
    }

    public function deleteWpBlog($id)
    {
        $wpBlog = WpBlog::find($id);
        $wpBlog->delete();

        // If success flash success message else flash error message
        if ($wpBlog) {
            session()->flash('success', 'Wordpress blog deleted successfully.');
        } else {
            session()->flash('error', 'There was an error deleting the Wordpress blog.');
        }
    }
}
